# PyWalletConnectV1

  Licence: LGPL v3
  Author: Toporin, based on [wallet-connect-kotlin by TrustWallet](https://github.com/trustwallet/wallet-connect-kotlin)
  Language: Python (>= 3.6)
  Homepage: https://github.com/Toporin/pywalletconnectv1

## Introduction

[WalletConnect](https://walletconnect.org/) python SDK, implements 1.0.0 websocket based protocol.


## Features

- [x] Connect and disconnect
- [x] Approve / Reject / Kill session
- [x] Approve and reject `eth_sign` / `personal_sign` / `eth_signTypedData`
- [x] Approve and reject `eth_signTransaction` / `eth_sendTransaction`
- [ ] Approve and reject `bnb_sign` (binance dex orders)
- [ ] session persistent / recovery

## Installation

TODO!

## Usage

TODO!
See '''pyWalletConnectV1.py''' and '''wc_callback.py''' for a basic example.

See [Satochip-Bridge](https://github.com/Toporin/Satochip-Bridge) for practical usage of this library.

## License & attribution

Pywalletconnectv1 is based on [wallet-connect-kotlin by TrustWallet](https://github.com/trustwallet/wallet-connect-kotlin).
Pywalletconnectv1 is available under the GPLV3 license. See the LICENSE file for more info.
